@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: bytestring-tree-builder
 version: 0.2.6
-id: bytestring-tree-builder-0.2.6-ad0389606a963ec8cd4543e227578133
-key: bytes_KmTFRSbz11J3Pi9BlWHCgl
+id: bytestring-tree-builder-0.2.6-f99a005d810c706c198f81b441dbead7
+key: bytes_BrIPG1t5NzQ2Woew5Fv6pa
 license: MIT
 copyright: (c) 2015, Nikita Volkov
 maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
@@ -26,12 +26,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/bytestring-tree-builder-0.2.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/bytestring-tree-builder-0.2.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/bytestring-tree-builder-0.2.6
-hs-libraries: HSbytestring-tree-builder-0.2.6-KmTFRSbz11J3Pi9BlWHCgl
+hs-libraries: HSbytestring-tree-builder-0.2.6-BrIPG1t5NzQ2Woew5Fv6pa
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-prelude-1-f3d581c11ed30ed2219a781ec92d2bd3
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-bytestring-tree-builder/html/bytestring-tree-builder.haddock
 haddock-html: /usr/share/doc/haskell-bytestring-tree-builder/html
